import numpy as np
import icet
from readData      import setLattice
from ase.db             import connect
from joblib import dump, load
from ase.io import read, write
from ase import Atoms
import os

# calculate the correlation vector of the final KMC structure  
basis_db_path = 'basis.db'
primCell_path = 'PRIM.POSCAR'
cutoffs   = [6, 6]
#cutoffs   = [6, 4]
#cutoffs   = [6]
corr_path = 'corr_basis.joblib'
#strucpath = 'slice_X_400K_0.9V.vasp'
strucpath = 'slice_X_400K_0.65V.vasp'
#strucpath = 'slice_X_400K_0.5V.vasp'
#strucpath = 'slice_X_400K_0.8V.vasp'
name = strucpath.strip('.vasp')[len("slice_X"):]
corr_target_path = 'corr_'+name+'.joblib'
print(name)

lattice = setLattice(primCell_path=primCell_path, cutoffs=cutoffs)
# structures as basis set to project the target structure onto
struc_pool, corr_basis = lattice.gen_struc_corr(basis_db_path, corr_path)

# Load target structure from KMC
#target_db_path = 'target.db'
#target_db = connect(target_db_path)
#for row in target_db.select():
    #structure = row.toatoms()
if os.path.exists(corr_target_path):
    corri = load(corr_target_path)
else:
    structure = read(strucpath, format='vasp')
    '''
    # cut the big supercell into small parts
    vdir= structure.get_scaled_positions()
    struc_slice = Atoms()
    frac = 8/128.0
    a0   = 1/128.0
    box = structure.get_cell()
    box[0] *= frac
    for atom in structure:
       i = atom.index
       xin = vdir[i][0] < frac-0.01+a0 and vdir[i][0] > a0-0.01
       if xin : struc_slice += structure[i]
    struc_slice.set_cell(box)
    struc_slice.set_pbc([1,1,1])
    '''
    corri = lattice.cs.get_cluster_vector(structure)
    dump(corri, corr_target_path)

A = np.array(corr_basis).transpose()
b = np.array(corri).transpose()
print(A.shape, b.shape)
x = np.linalg.lstsq(A, b, rcond=None)
print(x[0])

# quadratic optimization
from cvxopt import matrix, solvers
# Define QP parameters (with NumPy)
ATA = np.matmul(A.transpose(), A)
#print("P shape: ", ATA.shape)
ATb = np.matmul(A.transpose(), b)
P   = matrix(2*ATA)
q   = matrix(-2*ATb)
print("P: ", P)
print("q: ", q)
G   = matrix(-1*np.identity(len(ATA)))
h   = matrix(np.zeros(len(ATA)))
# Construct the QP, invoke solver
sol = solvers.qp(P,q,G,h)
# Extract optimal value and solution
print(sol['x'])
print(sol['primal objective'])

