import matplotlib.pyplot as plt
import re
import sys, os, pickle
import numpy as np

fig_width_pt = 246.0  # Get this from LaTeX using \showthe\columnwidth
inches_per_pt = 1.0/72.27               # Convert pt to inch
#golden_mean = (pl.sqrt(5)-1.0)/2.0         # Aesthetic ratio
golden_mean = 0.8
fig_width = fig_width_pt*inches_per_pt  # width in inches
fig_height = fig_width*golden_mean    # height in inches
fig_size =  [fig_width,fig_height]
params = {'backend': 'ps',
          'axes.labelsize': 10,
          #'text.fontsize': 10,
          'legend.fontsize': 8,
          'xtick.labelsize': 8,
          'ytick.labelsize': 8,
          #'text.usetex': True,
          'figure.figsize': fig_size}
plt.rcParams.update(params)

basis_names = np.loadtxt('basis_name', dtype=str)
print(basis_names)

resultf = 'out_400K_0.5V_cut660_near_alloy'
voltage = resultf.split('_')[2]
oxide_composition = np.loadtxt(resultf)
# normalize out O2
oxide_composition[0] = 0.0
oxide_composition /= np.sum(oxide_composition)
oxide_composition *= 100

category_colors = plt.get_cmap('RdYlGn')(
        np.linspace(0.15, 0.85, len(basis_names)))

fig, ax = plt.subplots(1, 1)
data = oxide_composition
data_cum = data.cumsum(axis=0)
for i, (colname, color) in enumerate(zip(basis_names, category_colors)):
      widths = data[i]
      starts = data_cum[i] - widths
      if widths < 0.1: continue
      ax.barh('0.5V', widths, left=starts, height=0.5,
              label=colname, color=color)
      xcenters = starts + widths / 2

ax.legend(ncol=len(basis_names), bbox_to_anchor=(0, 1), loc='lower left', fontsize='small')

plt.tight_layout()
plt.savefig(voltage+'.pdf')
#plt.show()





